==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/FilterRowDefinitionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { FilterRowDefinitionDescription } from "./FilterRowDefinitionDescription";
/**
 * @hidden
 */
export let FilterRowDefinitionDescriptionMetadata = /*@__PURE__*/ (() => {
    class FilterRowDefinitionDescriptionMetadata extends Base {
        static b(a) {
            if (FilterRowDefinitionDescriptionMetadata.a == null) {
                FilterRowDefinitionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FilterRowDefinitionDescriptionMetadata.c(FilterRowDefinitionDescriptionMetadata.a);
            }
            if (a.j(FilterRowDefinitionDescriptionMetadata.a)) {
                return;
            }
            a.y(FilterRowDefinitionDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
            a.item("PaddingLeft", "Number:int");
            a.item("PaddingTop", "Number:int");
            a.item("PaddingRight", "Number:int");
            a.item("PaddingBottom", "Number:int");
        }
        static d(a) {
            FilterRowDefinitionDescriptionMetadata.b(a);
            a.aa("FilterRowDefinition", () => new FilterRowDefinitionDescription());
            a.z("FilterRowDefinition", FilterRowDefinitionDescriptionMetadata.a);
        }
    }
    FilterRowDefinitionDescriptionMetadata.$t = /*@__PURE__*/ markType(FilterRowDefinitionDescriptionMetadata, 'FilterRowDefinitionDescriptionMetadata');
    FilterRowDefinitionDescriptionMetadata.a = null;
    return FilterRowDefinitionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/FilterRowDefinitionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { FilterRowDefinitionDescription } from "./FilterRowDefinitionDescription";
/**
 * @hidden
 */
export let FilterRowDefinitionDescriptionMetadata = /*@__PURE__*/ (() => {
    class FilterRowDefinitionDescriptionMetadata extends Base {
        static b(a) {
            if (FilterRowDefinitionDescriptionMetadata.a == null) {
                FilterRowDefinitionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FilterRowDefinitionDescriptionMetadata.c(FilterRowDefinitionDescriptionMetadata.a);
            }
            if (a.k(FilterRowDefinitionDescriptionMetadata.a)) {
                return;
            }
            a.aa(FilterRowDefinitionDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
            a.item("PaddingLeft", "Number:int");
            a.item("PaddingTop", "Number:int");
            a.item("PaddingRight", "Number:int");
            a.item("PaddingBottom", "Number:int");
        }
        static d(a) {
            FilterRowDefinitionDescriptionMetadata.b(a);
            a.ac("FilterRowDefinition", () => new FilterRowDefinitionDescription());
            a.ab("FilterRowDefinition", FilterRowDefinitionDescriptionMetadata.a);
        }
    }
    FilterRowDefinitionDescriptionMetadata.$t = /*@__PURE__*/ markType(FilterRowDefinitionDescriptionMetadata, 'FilterRowDefinitionDescriptionMetadata');
    FilterRowDefinitionDescriptionMetadata.a = null;
    return FilterRowDefinitionDescriptionMetadata;
})();
